/**********************************************************************************
* C Library for the display module families
* TFT2428T, TFT50D and TFT60D from XV-Display.de
*
* Section: Config.h
*
* Revision 1
*
* AVR and AVR Xmega microcontrollers,
* SoftwareSPI and HardwareSPI supported.
*
* Note: Some functions accesses the user flash memory
* and the micro sd card. First program flash.xvc into user
* flash memory and insert a micro sd card (FAT32) with example
* pictures. The package file flash.xvc (images and fonts)
* and example windows bitmap pictures are provided in this
* demo (see folder resources).
*
* Programming user flash memory:
* (1) insert micro sd card, formattet with FAT32 and flash.xvc
*     saved on it.
* (2) power on display module. programming process starts and
*     the status will be displayed.
* (3) if programming is completed, power off and remove micro
*     sd card.
*
* Recommended development environment:
*
* Atmel Studio 6
* ---> http://www.atmel.com/Microsite/atmel_studio6/default.aspx
* Developmentboard Nano from dev-tools.de.
* ---> http://www.dev-tools.de/index.php/development-boards/developmentboard-nano
*
* We invests time and resources providing this open source code,
* please support www.avr-praxis.de and open-source hardware
* by purchasing products from www.mikrocontroller-praxis.de!
*
* Written by Dirk Rodenhausen (dirk at avr-praxis.de)
*
* Our webpages:
* http://www.avr-praxis.de
* German discussion forum related to AVR microcontroller family.
* http://www.mikrocontroller-praxis.de
* Onlineshop where you can purchase the XV-Display display modules and
* the Dev-Tools Nano development board.
* http://www.dev-tools.de
* Further resources of products available from www.mikrocontroller-praxis.de.
*
*
* BSD license, all text above must be included in any redistribution.
* Please read the License.txt file.
* AVR is a registered trademark of Atmel corporation.
**********************************************************************************/


    /***
    Target architecture
    Currently available architectures: ARCH_AVR8, ARCH_XMEGA 
    ***/

    #define ARCH  ARCH_AVR8
    //  #define ARCH  ARCH_XMEGA

    /***
    Display module width an height in portrait mode
    ***/

    #define DISPLAY_MODULE_WIDTH  240
    #define DISPLAY_MODULE_HEIGHT 320


    /***
      Touchpanel
     
      If touchpanel enabled:
      TINT pin will be configurated as input with pullup resistor activated.
     
      If touchpanel not enabled:
      TINT pin is not assigned to display module and free for use in your application
    ***/

    #define DISPLAY_USE_TOUCHPANEL true  // true or false
	

    /***
    Interface mode HardwareSPI/SoftwareSPI
    If DISPLAY_SPI_MODE_HARDWARESPI is true, HardwareSPI is used, else SoftwareSPI is used
    ***/

    #define DISPLAY_SPI_MODE_HARDWARESPI false  // true or false



    #if (ARCH == ARCH_AVR8)

    /***
    Configuration of hardware related section for AVR microcontroller
    ***/    

        /***
        Display SPI Signal assignment
        ***/

        #define DISPLAY_SPI_PORT         PORTB
        #define DISPLAY_SPI_DATADIR      DDRB
        #define DISPLAY_SPI_INPORT       PINB
        #define DISPLAY_SPI_MISO         PB6
        #define DISPLAY_SPI_MOSI         PB5
        #define DISPLAY_SPI_SCK          PB7

        #define DISPLAY_SPI_SPEED_FCPU_DIV 2 // allowed values: 2, 4, 8, 16, 32, 64, 128 (for spi module only) 


        /***
        Display Control Signal assignment   
        ***/

        #define DISPLAY_CONTROL_PORT     PORTB
        #define DISPLAY_CONTROL_DATADIR  DDRB
        #define DISPLAY_CONTROL_INPORT   PINB
        #define DISPLAY_SIGNAL_BUSY      PB3
        #define DISPLAY_SIGNAL_CS        PB4
        #define DISPLAY_SIGNAL_TINT      PB2

    #elif (ARCH == ARCH_XMEGA)
    
    /***
    Configuration of hardware related section for XMEGA microcontroller
    ***/    
    
        /***
        Display SPI Signal assignment
        ***/

        #define DISPLAY_SPI_PORT         PORTD
        #define DISPLAY_SPI_MODULE       SPID       // Hardware SPI module
        #define DISPLAY_SPI_MISO         PIN6
        #define DISPLAY_SPI_MOSI         PIN5
        #define DISPLAY_SPI_SCK          PIN7

        #define DISPLAY_SPI_SPEED_FCPU_DIV 16 // allowed values: 2, 4, 8, 16, 32, 64, 128 (for spi module only) 

        /***
        Display Control Signal assignment   
        ***/

        #define DISPLAY_CONTROL_PORT     PORTD

        #define DISPLAY_SIGNAL_BUSY      PIN3
        #define DISPLAY_PINCTRL_BUSY     PIN3CTRL

        #define DISPLAY_SIGNAL_CS        PIN4

        #define DISPLAY_SIGNAL_TINT      PIN2
        #define DISPLAY_PINCTRL_TINT     PIN2CTRL
    
    
    #else
        #error The peripheral driver is not currently available for your selected architecture.
    #endif









